==> llm-docs-0.1.2.tgz: package/docs/modules/development/drupal_migration_plus/API_DOCUMENTATION.md <==
---
id: modules-development-drupal_migration_plus-API_DOCUMENTATION
---
# API Documentation

## Overview

Drupal Migration Plus provides a comprehensive REST API for programmatic access to migration functionality. All endpoints follow OpenAPI 3.0 standards and return JSON responses.

## Base URL

```
https://your-site.com/api/migration/field-mapping
```

## Authentication

API endpoints require proper Drupal authentication:

- **Session Authentication**: For browser-based requests
- **Basic Authentication**: For server-to-server communication
- **Bearer Token**: For applications using OAuth

Required permissions:
- `administer drupal migration plus` - Full API access
- `access content` - Read-only access to some endpoints

## Content Types

All API requests and responses use:
```
Content-Type: application/json
Accept: application/json
```

## API Endpoints

### Field Mapping Analysis

#### POST /analyze

Analyzes source fields and generates comprehensive mapping recommendations.

**Request Body:**
```json
{
  "source_fields": {
    "field_name": {
      "type": "text|textarea|number|image|file|date|email|url|etc",
      "name": "field_name",
      "label": "Field Label",
      "description": "Field description"
    }
  },
  "source_cms": "wordpress|joomla|drupal7|custom",
  "target_entity_type": "node|user|taxonomy_term|etc",
  "target_bundle": "article|page|etc",
  "options": {
    "confidence_threshold": 0.5,
    "enable_concatenation": true,
    "enable_sdc_recommendations": true
  }
}
```

**Response:**
```json
{
  "status": "success",
  "data": {
    "direct_mappings": {
      "source_field_name": {
        "target_field": "drupal_field_name",
        "confidence": 0.95,
        "mapping_type": "direct",
        "transformation_required": false,
        "ai_reasoning": "Field name and type match exactly"
      }
    },
    "concatenation_opportunities": {
      "name_concatenation": {
        "type": "concatenation",
        "source_fields": ["first_name", "last_name"],
        "target_field": "field_full_name",
        "separator": " ",
        "confidence": 0.95,
        "preview_example": "[first_name] [last_name]"
      }
    },
    "custom_field_conversions": {},
    "sdc_component_mappings": {},
    "validation_rules": {
      "email_field": {
        "rules": [
          {
            "type": "email",
            "message": "Please enter a valid email address"
          }
        ],
        "real_time": true,
        "confidence": 0.9
      }
    },
    "transformation_pipeline": {
      "source_field": {
        "transformations": [
          {
            "step": "sanitize",
            "description": "Remove malicious content and normalize data",
            "processor": "sanitize_processor",
            "confidence": 1.0
          }
        ],
        "estimated_processing_time": "low",
        "complexity": "medium"
      }
    },
    "confidence_summary": {
      "average": 0.87,
      "high_confidence": 5,
      "medium_confidence": 2,
      "low_confidence": 1
    },
    "recommendations": [
      {
        "type": "review_required",
        "priority": "high",
        "message": "1 field mapping requires manual review",
        "action": "Review low-confidence mappings and adjust manually"
      }
    ]
  },
  "timestamp": 1640995200,
  "api_version": "1.0.0"
}
```

### Real-time Validation

#### POST /validate

Validates field mappings in real-time with immediate feedback.

**Request Body:**
```json
{
  "mappings": {
    "source_field": {
      "target_field": "drupal_field",
      "confidence": 0.95,
      "performance_impact": "low|medium|high"
    }
  },
  "target_entity_type": "node",
  "target_bundle": "article"
}
```

**Response:**
```json
{
  "status": "success",
  "data": {
    "valid": true,
    "errors": [
      {
        "field": "source_field",
        "message": "Target field 'nonexistent_field' does not exist",
        "severity": "error"
      }
    ],
    "warnings": [
      {
        "field": "source_field",
        "message": "Low confidence mapping (0.3)",
        "severity": "warning"
      }
    ],
    "suggestions": [],
    "performance_warnings": [
      {
        "field": "source_field",
        "message": "High performance impact transformation detected",
        "suggestion": "Consider batch processing for this field"
      }
    ]
  },
  "timestamp": 1640995200
}
```

### Concatenation Preview

#### POST /concatenation-preview

Generates preview for field concatenation with sample data.

**Request Body:**
```json
{
  "source_fields": ["first_name", "last_name"],
  "separator": " ",
  "sample_data": {
    "first_name": "John",
    "last_name": "Doe"
  }
}
```

**Response:**
```json
{
  "status": "success",
  "data": {
    "preview": "John Doe",
    "field_count": 2,
    "estimated_length": 8,
    "separator": " "
  }
}
```

### Target Fields Discovery

#### GET /target-fields/{entity_type}/{bundle}

Retrieves available target fields for a specific entity type and bundle.

**Parameters:**
- `entity_type`: Target entity type (node, user, etc.)
- `bundle`: Target bundle (article, page, etc.)

**Response:**
```json
{
  "status": "success",
  "data": {
    "fields": {
      "title": {
        "name": "title",
        "type": "string",
        "label": "Title",
        "description": "The title of the content",
        "required": true,
        "cardinality": 1,
        "configurable": true
      },
      "body": {
        "name": "body",
        "type": "text_with_summary",
        "label": "Body",
        "description": "The main content",
        "required": false,
        "cardinality": 1,
        "configurable": true
      }
    }
  },
  "entity_type": "node",
  "bundle": "article"
}
```

### SDC Recommendations

#### POST /sdc-recommendations

Generates Single Directory Component recommendations for complex field groups.

**Request Body:**
```json
{
  "source_fields": {
    "title": {"type": "text"},
    "content": {"type": "textarea"},
    "image": {"type": "image"}
  },
  "complexity_threshold": 0.7
}
```

**Response:**
```json
{
  "status": "success",
  "data": {
    "components": {
      "hero_component": {
        "component_name": "hero-banner",
        "component_type": "organism",
        "source_fields": ["title", "content", "image"],
        "template_suggestion": "hero-banner.html.twig",
        "css_classes": ["hero", "banner"],
        "confidence": 0.85
      }
    },
    "total_components": 1,
    "estimated_development_time": "2-4 hours"
  }
}
```

### API Schema

#### GET /schema

Returns the complete OpenAPI 3.0 schema for the API.

**Response:**
```json
{
  "openapi": "3.0.0",
  "info": {
    "title": "Drupal Migration Plus AI Field Mapping API",
    "version": "1.0.0",
    "description": "AI-powered field mapping interface for multi-CMS migrations to Drupal 11"
  },
  "servers": [
    {
      "url": "/api/migration/field-mapping",
      "description": "Field Mapping API Server"
    }
  ],
  "paths": {
    "/analyze": {
      "post": {
        "summary": "Analyze source fields for AI-powered mapping recommendations",
        "tags": ["Field Mapping"],
        "requestBody": {
          "required": true,
          "content": {
            "application/json": {
              "schema": {
                "$ref": "#/components/schemas/AnalyzeRequest"
              }
            }
          }
        }
      }
    }
  },
  "components": {
    "schemas": {
      "FieldMapping": {
        "type": "object",
        "properties": {
          "source_field": {"type": "string"},
          "target_field": {"type": "string"},
          "confidence": {"type": "number", "minimum": 0, "maximum": 1}
        }
      }
    }
  }
}
```

## Error Handling

### Standard Error Response

```json
{
  "error": "Error message",
  "message": "Detailed error description",
  "code": 400,
  "timestamp": 1640995200
}
```

### HTTP Status Codes

- `200 OK` - Request successful
- `400 Bad Request` - Invalid request data
- `401 Unauthorized` - Authentication required
- `403 Forbidden` - Insufficient permissions
- `404 Not Found` - Endpoint or resource not found
- `500 Internal Server Error` - Server error

## Rate Limiting

API endpoints are subject to rate limiting:

- **Authenticated requests**: 1000 requests per hour
- **Anonymous requests**: 100 requests per hour
- **AI analysis requests**: 100 requests per hour (due to AI processing costs)

Rate limit headers are included in responses:
```
X-RateLimit-Limit: 1000
X-RateLimit-Remaining: 999
X-RateLimit-Reset: 1640998800
```

## Code Examples

### JavaScript (Fetch API)

```javascript
async function analyzeFields(sourceFields, sourceCms, targetEntityType, targetBundle) {
  const response = await fetch('/api/migration/field-mapping/analyze', {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json',
      'X-CSRF-Token': drupalSettings.csrf_token
    },
    body: JSON.stringify({
      source_fields: sourceFields,
      source_cms: sourceCms,
      target_entity_type: targetEntityType,
      target_bundle: targetBundle
    })
  });
  
  if (!response.ok) {
    throw new Error(`HTTP error! status: ${response.status}`);
  }
  
  return await response.json();
}
```

### PHP (Guzzle)

```php
use GuzzleHttp\Client;

$client = new Client(['base_uri' => 'https://your-site.com']);

$response = $client->post('/api/migration/field-mapping/analyze', [
  'json' => [
    'source_fields' => $sourceFields,
    'source_cms' => 'wordpress',
    'target_entity_type' => 'node',
    'target_bundle' => 'article'
  ],
  'headers' => [
    'Content-Type' => 'application/json',
    'Authorization' => 'Bearer ' . $token
  ]
]);

$data = json_decode($response->getBody(), true);
```

### Python (Requests)

```python
import requests

url = 'https://your-site.com/api/migration/field-mapping/analyze'
data = {
    'source_fields': source_fields,
    'source_cms': 'wordpress',
    'target_entity_type': 'node',
    'target_bundle': 'article'
}

response = requests.post(url, json=data, headers={
    'Content-Type': 'application/json',
    'Authorization': f'Bearer {token}'
})

if response.status_code == 200:
    result = response.json()
else:
    print(f'Error: {response.status_code}')
```

## SDKs and Libraries

### JavaScript SDK

```bash
npm install @drupal/migration-plus-sdk
```

```javascript
import { MigrationPlusClient } from '@drupal/migration-plus-sdk';

const client = new MigrationPlusClient({
  baseUrl: 'https://your-site.com',
  apiKey: 'your-api-key'
});

const analysis = await client.analyzeFields({
  sourceFields: fields,
  sourceCms: 'wordpress',
  targetEntityType: 'node',
  targetBundle: 'article'
});
```

### PHP SDK

```bash
composer require drupal/migration-plus-php-sdk
```

```php
use Drupal\MigrationPlus\Client;

$client = new Client([
  'base_uri' => 'https://your-site.com',
  'api_key' => 'your-api-key'
]);

$analysis = $client->analyzeFields([
  'source_fields' => $fields,
  'source_cms' => 'wordpress',
  'target_entity_type' => 'node',
  'target_bundle' => 'article'
]);
```

## Webhooks

Configure webhooks to receive notifications about migration events:

### Webhook Configuration

```json
{
  "url": "https://your-app.com/webhook",
  "events": ["migration.completed", "mapping.validated", "error.occurred"],
  "secret": "your-webhook-secret"
}
```

### Webhook Payload

```json
{
  "event": "migration.completed",
  "timestamp": 1640995200,
  "data": {
    "migration_id": "migration_123",
    "status": "completed",
    "processed_items": 1500,
    "errors": 0
  },
  "signature": "sha256=..."
}
```

This API documentation provides comprehensive coverage of all available endpoints, request/response formats, and integration examples for the Drupal Migration Plus platform.

==> llm-docs-0.1.5.tgz: package/docs/modules/development/drupal_migration_plus/API_DOCUMENTATION.md <==
---
id: modules-development-drupal_migration_plus-API_DOCUMENTATION
---
# API Documentation

## Overview

Drupal Migration Plus provides a comprehensive REST API for programmatic access to migration functionality. All endpoints follow OpenAPI 3.0 standards and return JSON responses.

## Base URL

```
https://your-site.com/api/migration/field-mapping
```

## Authentication

API endpoints require proper Drupal authentication:

- **Session Authentication**: For browser-based requests
- **Basic Authentication**: For server-to-server communication
- **Bearer Token**: For applications using OAuth

Required permissions:
- `administer drupal migration plus` - Full API access
- `access content` - Read-only access to some endpoints

## Content Types

All API requests and responses use:
```
Content-Type: application/json
Accept: application/json
```

## API Endpoints

### Field Mapping Analysis

#### POST /analyze

Analyzes source fields and generates comprehensive mapping recommendations.

**Request Body:**
```json
{
  "source_fields": {
    "field_name": {
      "type": "text|textarea|number|image|file|date|email|url|etc",
      "name": "field_name",
      "label": "Field Label",
      "description": "Field description"
    }
  },
  "source_cms": "wordpress|joomla|drupal7|custom",
  "target_entity_type": "node|user|taxonomy_term|etc",
  "target_bundle": "article|page|etc",
  "options": {
    "confidence_threshold": 0.5,
    "enable_concatenation": true,
    "enable_sdc_recommendations": true
  }
}
```

**Response:**
```json
{
  "status": "success",
  "data": {
    "direct_mappings": {
      "source_field_name": {
        "target_field": "drupal_field_name",
        "confidence": 0.95,
        "mapping_type": "direct",
        "transformation_required": false,
        "ai_reasoning": "Field name and type match exactly"
      }
    },
    "concatenation_opportunities": {
      "name_concatenation": {
        "type": "concatenation",
        "source_fields": ["first_name", "last_name"],
        "target_field": "field_full_name",
        "separator": " ",
        "confidence": 0.95,
        "preview_example": "[first_name] [last_name]"
      }
    },
    "custom_field_conversions": {},
    "sdc_component_mappings": {},
    "validation_rules": {
      "email_field": {
        "rules": [
          {
            "type": "email",
            "message": "Please enter a valid email address"
          }
        ],
        "real_time": true,
        "confidence": 0.9
      }
    },
    "transformation_pipeline": {
      "source_field": {
        "transformations": [
          {
            "step": "sanitize",
            "description": "Remove malicious content and normalize data",
            "processor": "sanitize_processor",
            "confidence": 1.0
          }
        ],
        "estimated_processing_time": "low",
        "complexity": "medium"
      }
    },
    "confidence_summary": {
      "average": 0.87,
      "high_confidence": 5,
      "medium_confidence": 2,
      "low_confidence": 1
    },
    "recommendations": [
      {
        "type": "review_required",
        "priority": "high",
        "message": "1 field mapping requires manual review",
        "action": "Review low-confidence mappings and adjust manually"
      }
    ]
  },
  "timestamp": 1640995200,
  "api_version": "1.0.0"
}
```

### Real-time Validation

#### POST /validate

Validates field mappings in real-time with immediate feedback.

**Request Body:**
```json
{
  "mappings": {
    "source_field": {
      "target_field": "drupal_field",
      "confidence": 0.95,
      "performance_impact": "low|medium|high"
    }
  },
  "target_entity_type": "node",
  "target_bundle": "article"
}
```

**Response:**
```json
{
  "status": "success",
  "data": {
    "valid": true,
    "errors": [
      {
        "field": "source_field",
        "message": "Target field 'nonexistent_field' does not exist",
        "severity": "error"
      }
    ],
    "warnings": [
      {
        "field": "source_field",
        "message": "Low confidence mapping (0.3)",
        "severity": "warning"
      }
    ],
    "suggestions": [],
    "performance_warnings": [
      {
        "field": "source_field",
        "message": "High performance impact transformation detected",
        "suggestion": "Consider batch processing for this field"
      }
    ]
  },
  "timestamp": 1640995200
}
```

### Concatenation Preview

#### POST /concatenation-preview

Generates preview for field concatenation with sample data.

**Request Body:**
```json
{
  "source_fields": ["first_name", "last_name"],
  "separator": " ",
  "sample_data": {
    "first_name": "John",
    "last_name": "Doe"
  }
}
```

**Response:**
```json
{
  "status": "success",
  "data": {
    "preview": "John Doe",
    "field_count": 2,
    "estimated_length": 8,
    "separator": " "
  }
}
```

### Target Fields Discovery

#### GET /target-fields/\{entity_type\}/\{bundle\}

Retrieves available target fields for a specific entity type and bundle.

**Parameters:**
- `entity_type`: Target entity type (node, user, etc.)
- `bundle`: Target bundle (article, page, etc.)

**Response:**
```json
{
  "status": "success",
  "data": {
    "fields": {
      "title": {
        "name": "title",
        "type": "string",
        "label": "Title",
        "description": "The title of the content",
        "required": true,
        "cardinality": 1,
        "configurable": true
      },
      "body": {
        "name": "body",
        "type": "text_with_summary",
        "label": "Body",
        "description": "The main content",
        "required": false,
        "cardinality": 1,
        "configurable": true
      }
    }
  },
  "entity_type": "node",
  "bundle": "article"
}
```

### SDC Recommendations

#### POST /sdc-recommendations

Generates Single Directory Component recommendations for complex field groups.

**Request Body:**
```json
{
  "source_fields": {
    "title": {"type": "text"},
    "content": {"type": "textarea"},
    "image": {"type": "image"}
  },
  "complexity_threshold": 0.7
}
```

**Response:**
```json
{
  "status": "success",
  "data": {
    "components": {
      "hero_component": {
        "component_name": "hero-banner",
        "component_type": "organism",
        "source_fields": ["title", "content", "image"],
        "template_suggestion": "hero-banner.html.twig",
        "css_classes": ["hero", "banner"],
        "confidence": 0.85
      }
    },
    "total_components": 1,
    "estimated_development_time": "2-4 hours"
  }
}
```

### API Schema

#### GET /schema

Returns the complete OpenAPI 3.0 schema for the API.

**Response:**
```json
{
  "openapi": "3.0.0",
  "info": {
    "title": "Drupal Migration Plus AI Field Mapping API",
    "version": "1.0.0",
    "description": "AI-powered field mapping interface for multi-CMS migrations to Drupal 11"
  },
  "servers": [
    {
      "url": "/api/migration/field-mapping",
      "description": "Field Mapping API Server"
    }
  ],
  "paths": {
    "/analyze": {
      "post": {
        "summary": "Analyze source fields for AI-powered mapping recommendations",
        "tags": ["Field Mapping"],
        "requestBody": {
          "required": true,
          "content": {
            "application/json": {
              "schema": {
                "$ref": "#/components/schemas/AnalyzeRequest"
              }
            }
          }
        }
      }
    }
  },
  "components": {
    "schemas": {
      "FieldMapping": {
        "type": "object",
        "properties": {
          "source_field": {"type": "string"},
          "target_field": {"type": "string"},
          "confidence": {"type": "number", "minimum": 0, "maximum": 1}
        }
      }
    }
  }
}
```

## Error Handling

### Standard Error Response

```json
{
  "error": "Error message",
  "message": "Detailed error description",
  "code": 400,
  "timestamp": 1640995200
}
```

### HTTP Status Codes

- `200 OK` - Request successful
- `400 Bad Request` - Invalid request data
- `401 Unauthorized` - Authentication required
- `403 Forbidden` - Insufficient permissions
- `404 Not Found` - Endpoint or resource not found
- `500 Internal Server Error` - Server error

## Rate Limiting

API endpoints are subject to rate limiting:

- **Authenticated requests**: 1000 requests per hour
- **Anonymous requests**: 100 requests per hour
- **AI analysis requests**: 100 requests per hour (due to AI processing costs)

Rate limit headers are included in responses:
```
X-RateLimit-Limit: 1000
X-RateLimit-Remaining: 999
X-RateLimit-Reset: 1640998800
```

## Code Examples

### JavaScript (Fetch API)

```javascript
async function analyzeFields(sourceFields, sourceCms, targetEntityType, targetBundle) {
  const response = await fetch('/api/migration/field-mapping/analyze', {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json',
      'X-CSRF-Token': drupalSettings.csrf_token
    },
    body: JSON.stringify({
      source_fields: sourceFields,
      source_cms: sourceCms,
      target_entity_type: targetEntityType,
      target_bundle: targetBundle
    })
  });
  
  if (!response.ok) {
    throw new Error(`HTTP error! status: ${response.status}`);
  }
  
  return await response.json();
}
```

### PHP (Guzzle)

```php
use GuzzleHttp\Client;

$client = new Client(['base_uri' => 'https://your-site.com']);

$response = $client->post('/api/migration/field-mapping/analyze', [
  'json' => [
    'source_fields' => $sourceFields,
    'source_cms' => 'wordpress',
    'target_entity_type' => 'node',
    'target_bundle' => 'article'
  ],
  'headers' => [
    'Content-Type' => 'application/json',
    'Authorization' => 'Bearer ' . $token
  ]
]);

$data = json_decode($response->getBody(), true);
```

### Python (Requests)

```python
import requests

url = 'https://your-site.com/api/migration/field-mapping/analyze'
data = {
    'source_fields': source_fields,
    'source_cms': 'wordpress',
    'target_entity_type': 'node',
    'target_bundle': 'article'
}

response = requests.post(url, json=data, headers={
    'Content-Type': 'application/json',
    'Authorization': f'Bearer {token}'
})

if response.status_code == 200:
    result = response.json()
else:
    print(f'Error: {response.status_code}')
```

## SDKs and Libraries

### JavaScript SDK

```bash
npm install @drupal/migration-plus-sdk
```

```javascript
import { MigrationPlusClient } from '@drupal/migration-plus-sdk';

const client = new MigrationPlusClient({
  baseUrl: 'https://your-site.com',
  apiKey: 'your-api-key'
});

const analysis = await client.analyzeFields({
  sourceFields: fields,
  sourceCms: 'wordpress',
  targetEntityType: 'node',
  targetBundle: 'article'
});
```

### PHP SDK

```bash
composer require drupal/migration-plus-php-sdk
```

```php
use Drupal\MigrationPlus\Client;

$client = new Client([
  'base_uri' => 'https://your-site.com',
  'api_key' => 'your-api-key'
]);

$analysis = $client->analyzeFields([
  'source_fields' => $fields,
  'source_cms' => 'wordpress',
  'target_entity_type' => 'node',
  'target_bundle' => 'article'
]);
```

## Webhooks

Configure webhooks to receive notifications about migration events:

### Webhook Configuration

```json
{
  "url": "https://your-app.com/webhook",
  "events": ["migration.completed", "mapping.validated", "error.occurred"],
  "secret": "your-webhook-secret"
}
```

### Webhook Payload

```json
{
  "event": "migration.completed",
  "timestamp": 1640995200,
  "data": {
    "migration_id": "migration_123",
    "status": "completed",
    "processed_items": 1500,
    "errors": 0
  },
  "signature": "sha256=..."
}
```

This API documentation provides comprehensive coverage of all available endpoints, request/response formats, and integration examples for the Drupal Migration Plus platform.
